@@ -14,14 +14,18 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from mapproxy.core.request import url_decode, Request, NoCaseMultiDict
+from mapproxy.core.srs import SRS
+from mapproxy.core.request import url_decode, Request, NoCaseMultiDict, RequestParams, BaseRequest
 from mapproxy.tms.request import TMSRequest, tile_request, TileRequest
 from mapproxy.wms.request import (wms_request, WMSMapRequest, WMSMapRequestParams,
-                              WMS111MapRequest, WMS100MapRequest, WMS130MapRequest)
+                              WMS111MapRequest, WMS100MapRequest, WMS130MapRequest,
+                              WMS111FeatureInfoRequest)
 from mapproxy.core.exceptions import RequestError
 from mapproxy.wms.exceptions import (WMS111ExceptionHandler, WMSImageExceptionHandler,
                                      WMSBlankExceptionHandler)
 from mapproxy.tests.http import make_wsgi_env
+
+import pickle
 from nose.tools import eq_
 
 class TestNoCaseMultiDict(object):
@@ -186,6 +190,26 @@ class TestWMS130MapRequest(TestWMSMapRequest):
         assert isinstance(req2, WMS111MapRequest)
         
     
+class TestWMS111FeatureInfoRequest(TestWMSMapRequest):
+    def setup(self):
+        TestWMSMapRequest.setup(self)
+        self.base_req['request'] = 'GetFeatureInfo'
+        self.base_req['x'] = '100'
+        self.base_req['y'] = '150'
+        self.base_req['query_layers'] = 'foo'
+        
+    def test_basic_request(self):
+        req = wms_request(DummyRequest(self.base_req))#, validate=False)
+        assert isinstance(req, WMS111FeatureInfoRequest)
+    
+    def test_pos(self):
+        req = wms_request(DummyRequest(self.base_req))
+        eq_(req.params.pos, (100, 150))
+    
+    def test_pos_coords(self):
+        req = wms_request(DummyRequest(self.base_req))
+        eq_(req.params.pos_coords, (7.25, 50.5))
+        
 
 class TestRequest(object):
     def setup(self):
@@ -291,6 +315,8 @@ class TestWMSMapRequestParams(object):
         assert self.m.srs == 'EPSG:0815'
         del self.m['srs']
         assert self.m.srs is None
+        self.m.srs = SRS('EPSG:4326')
+        assert self.m.srs == 'EPSG:4326'
     def test_layers(self):
         assert list(self.m.layers) == ['bar', 'foo']
     def test_query_string(self):
@@ -440,3 +466,9 @@ class TestTileRequest(object):
         eq_(tile_req.tile, (2, 3, 5))
         eq_(tile_req.format, 'png')
         eq_(tile_req.layer, 'osm_EPSG4326')
+
+def test_request_params_pickle():
+    params = RequestParams(dict(foo='bar', zing='zong'))
+    params2 = pickle.loads(pickle.dumps(params, 2))
+    assert params.params == params2.params
+    
